Thank you for your contribution to TLS. 
Before submitting this PR, please make sure:

- [ ] Your code builds clean without any errors or warnings
- [ ] [Existing test cases](https://github.com/hippke/tls/tree/master/transitleastsquares/tests) work correctly
- [ ] New test cases have been added to cover the additional and/or changed functionality
